0.5.0
-----
- Fixed Python 3 support

0.4.4
-----
- Added option to target file extensions for uncompressed files

0.4.3
-----
- Added CustomException coverage if opening archive fails

0.4.2
-----
- Added CustomException option to load() decorator

0.4.1
-----
- Excluded extraneous '.' when saving zip archives

0.4.0
-----
- Added support for file-like objects when saving or loading archives
- Added support for folderPaths when saving archives
- Increased test coverage to 100%

0.3.0
-----
- Added Archive class

0.2.0
-----
- Ported code from zip_store
- Added support for .tar.gz .tar.bz2 .tar
